Source code & Development:
    https://mangenerator.sourceforge.io
Doxygen documentation:
    http://turulomio.users.sourceforge.net/doxygen/mangenerator/

Description
===========

License
=======
GPL-3

Dependencies
============

None, other than Python. Tested on Python 3 

Usage
=====


Changelog
=========
0.2.0
  * Basic funcionality

